PrivateKey

Struct PrivateKey 

pub struct PrivateKey(/* private fields */);
Represents a private key.

The private key allows creating designated verifier signatures. These signatures require the private key of that verifier to be validated. Furthermore, the verifier can use their private key to forge valid signatures which designate them.

Implementations

Source

impl PrivateKey

pub fn from_bytes(data: [u8; 32]) -> Option<Self>

Attempt to unmarshall bytes into a private key.

This can fail if the bytes don’t represent a valid private key.

pub fn to_bytes(&self) -> [u8; 32]

Marshall this private key into bytes.

pub fn sign<R: RngCore + CryptoRng>( &self, rng: &mut R, designee: &PublicKey, message: &[u8], ) -> Signature

Sign a message, designated to a specific verifier.

pub fn forge<R: RngCore + CryptoRng>( &self, rng: &mut R, signer: &PublicKey, message: &[u8], ) -> Signature

As a verifier, forge a message from a signer, designated to yourself.

pub fn verify( &self, signer: &PublicKey, message: &[u8], signature: &Signature, ) -> bool

Verify that a signer’s signature on a message is valid.

You must have been designated the verifier for this to work.