pub struct PrivateKey(/* private fields */);Expand description
Represents a private key.
The private key allows creating designated verifier signatures. These signatures require the private key of that verifier to be validated. Furthermore, the verifier can use their private key to forge valid signatures which designate them.
Implementations
Sourceimpl PrivateKey
impl PrivateKey
Sourcepub fn from_bytes(data: [u8; 32]) -> Option<Self>
pub fn from_bytes(data: [u8; 32]) -> Option<Self>
Attempt to unmarshall bytes into a private key.
This can fail if the bytes don’t represent a valid private key.
Sourcepub fn sign<R: RngCore + CryptoRng>(
&self,
rng: &mut R,
designee: &PublicKey,
message: &[u8],
) -> Signature
pub fn sign<R: RngCore + CryptoRng>( &self, rng: &mut R, designee: &PublicKey, message: &[u8], ) -> Signature
Sign a message, designated to a specific verifier.